summaryrefslogtreecommitdiff
path: root/src/mongo/db/clientcursor.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/mongo/db/clientcursor.h')
-rw-r--r--src/mongo/db/clientcursor.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/src/mongo/db/clientcursor.h b/src/mongo/db/clientcursor.h
index 9e7d35ade9a..8ae75473496 100644
--- a/src/mongo/db/clientcursor.h
+++ b/src/mongo/db/clientcursor.h
@@ -448,15 +448,15 @@ private:
boost::optional<uint32_t> _queryHash;
// If boost::none, telemetry should not be collected for this cursor.
- boost::optional<std::size_t> _telemetryStoreKeyHash;
+ boost::optional<std::size_t> _queryStatsStoreKeyHash;
// TODO: SERVER-73152 remove telemetryStoreKey when RequestShapifier is used for agg.
- boost::optional<BSONObj> _telemetryStoreKey;
+ boost::optional<BSONObj> _queryStatsStoreKey;
// Metrics that are accumulated over the lifetime of the cursor, incremented with each getMore.
// Useful for diagnostics like telemetry.
OpDebug::AdditiveMetrics _metrics;
// The RequestShapifier used by telemetry to shapify the request payload into the telemetry
// store key.
- std::unique_ptr<telemetry::RequestShapifier> _telemetryRequestShapifier;
+ std::unique_ptr<query_stats::RequestShapifier> _queryStatsRequestShapifier;
// Flag to decide if diagnostic information should be omitted.
bool _shouldOmitDiagnosticInformation{false};
@@ -598,7 +598,7 @@ void startClientCursorMonitor();
* Currently, telemetry is only collected for find and aggregate requests (and their subsequent
* getMore requests), so these should only be called from those request paths.
*/
-void collectTelemetryMongod(OperationContext* opCtx, ClientCursorPin& cursor);
-void collectTelemetryMongod(OperationContext* opCtx,
- std::unique_ptr<telemetry::RequestShapifier> requestShapifier);
+void collectQueryStatsMongod(OperationContext* opCtx, ClientCursorPin& cursor);
+void collectQueryStatsMongod(OperationContext* opCtx,
+ std::unique_ptr<query_stats::RequestShapifier> requestShapifier);
} // namespace mongo
@@ -448,15 +448,15 @@ private:
// Metrics that are accumulated over the lifetime of the cursor, incremented with each getMore.
- // Useful for diagnostics like telemetry.
+ // Useful for diagnostics like queryStats.
OpDebug::AdditiveMetrics _metrics;
// The RequestShapifier used by telemetry to shapify the request payload into the telemetry